@@ -32,6 +32,7 @@ from pydantic import (
     field_serializer,
     field_validator,
     model_validator,
+    with_config,
 )
 from pydantic._internal._mock_val_ser import MockValSer
 from pydantic.dataclasses import is_pydantic_dataclass, rebuild_dataclass
@@ -39,6 +40,16 @@ from pydantic.fields import Field, FieldInfo
 from pydantic.json_schema import model_json_schema
 
 
+def test_cannot_create_dataclass_from_basemodel_subclass():
+    msg = 'Cannot create a Pydantic dataclass from SubModel as it is already a Pydantic model'
+
+    with pytest.raises(PydanticUserError, match=msg):
+
+        @pydantic.dataclasses.dataclass
+        class SubModel(BaseModel):
+            pass
+
+
 def test_simple():
     @pydantic.dataclasses.dataclass
     class MyDataclass:
@@ -1352,6 +1363,7 @@ def test_discriminated_union_basemodel_instance_value():
 
     t = Top(sub=A(l='a'))
     assert isinstance(t, Top)
+    # insert_assert(model_json_schema(Top))
     assert model_json_schema(Top) == {
         'title': 'Top',
         'type': 'object',
@@ -1364,8 +1376,18 @@ def test_discriminated_union_basemodel_instance_value():
         },
         'required': ['sub'],
         '$defs': {
-            'A': {'properties': {'l': {'const': 'a', 'title': 'L'}}, 'required': ['l'], 'title': 'A', 'type': 'object'},
-            'B': {'properties': {'l': {'const': 'b', 'title': 'L'}}, 'required': ['l'], 'title': 'B', 'type': 'object'},
+            'A': {
+                'properties': {'l': {'const': 'a', 'enum': ['a'], 'title': 'L', 'type': 'string'}},
+                'required': ['l'],
+                'title': 'A',
+                'type': 'object',
+            },
+            'B': {
+                'properties': {'l': {'const': 'b', 'enum': ['b'], 'title': 'L', 'type': 'string'}},
+                'required': ['l'],
+                'title': 'B',
+                'type': 'object',
+            },
         },
     }
 
@@ -1621,6 +1643,78 @@ def test_cross_module_cyclic_reference_dataclass(create_module):
     ]
 
 
+@pytest.mark.parametrize(
+    'dataclass_decorator',
+    [
+        pydantic.dataclasses.dataclass,
+        dataclasses.dataclass,
+    ],
+    ids=['pydantic', 'stdlib'],
+)
+def test_base_dataclasses_annotations_resolving(create_module, dataclass_decorator: Callable):
+    @create_module
+    def module():
+        import dataclasses
+        from typing import NewType
+
+        OddInt = NewType('OddInt', int)
+
+        @dataclasses.dataclass
+        class D1:
+            d1: 'OddInt'
+            s: str
+
+            __pydantic_config__ = {'str_to_lower': True}
+
+    @dataclass_decorator
+    class D2(module.D1):
+        d2: int
+
+    assert TypeAdapter(D2).validate_python({'d1': 1, 'd2': 2, 's': 'ABC'}) == D2(d1=1, d2=2, s='abc')
+
+
+@pytest.mark.parametrize(
+    'dataclass_decorator',
+    [
+        pydantic.dataclasses.dataclass,
+        dataclasses.dataclass,
+    ],
+    ids=['pydantic', 'stdlib'],
+)
+def test_base_dataclasses_annotations_resolving_with_override(create_module, dataclass_decorator: Callable):
+    @create_module
+    def module1():
+        import dataclasses
+        from typing import NewType
+
+        IDType = NewType('IDType', int)
+
+        @dataclasses.dataclass
+        class D1:
+            db_id: 'IDType'
+
+            __pydantic_config__ = {'str_to_lower': True}
+
+    @create_module
+    def module2():
+        import dataclasses
+        from typing import NewType
+
+        IDType = NewType('IDType', str)
+
+        @dataclasses.dataclass
+        class D2:
+            db_id: 'IDType'
+            s: str
+
+            __pydantic_config__ = {'str_to_lower': False}
+
+    @dataclass_decorator
+    class D3(module1.D1, module2.D2): ...
+
+    assert TypeAdapter(D3).validate_python({'db_id': 42, 's': 'ABC'}) == D3(db_id=42, s='abc')
+
+
 @pytest.mark.skipif(sys.version_info < (3, 10), reason='kw_only is not available in python < 3.10')
 def test_kw_only():
     @pydantic.dataclasses.dataclass(kw_only=True)
@@ -1709,8 +1803,7 @@ def test_kw_only_inheritance(decorator1, decorator2):
 
 def test_extra_forbid_list_no_error():
     @pydantic.dataclasses.dataclass(config=dict(extra='forbid'))
-    class Bar:
-        ...
+    class Bar: ...
 
     @pydantic.dataclasses.dataclass
     class Foo:
@@ -1721,8 +1814,7 @@ def test_extra_forbid_list_no_error():
 
 def test_extra_forbid_list_error():
     @pydantic.dataclasses.dataclass(config=ConfigDict(extra='forbid'))
-    class Bar:
-        ...
+    class Bar: ...
 
     with pytest.raises(ValidationError, match=r'a\s+Unexpected keyword argument'):
         Bar(a=1)
@@ -1751,6 +1843,7 @@ def test_model_validator_before():
         b: float
 
         @model_validator(mode='before')
+        @classmethod
         def double_b(cls, v: ArgsKwargs):
             v.kwargs['b'] *= 2
             return v
@@ -2406,6 +2499,24 @@ def test_model_config_override_in_decorator_empty_config() -> None:
     assert ta.validate_python({'x': 'ABC '}).x == 'ABC '
 
 
+def test_dataclasses_with_config_decorator():
+    @dataclasses.dataclass
+    @with_config(ConfigDict(str_to_lower=True))
+    class Model1:
+        x: str
+
+    ta = TypeAdapter(Model1)
+    assert ta.validate_python({'x': 'ABC'}).x == 'abc'
+
+    @with_config(ConfigDict(str_to_lower=True))
+    @dataclasses.dataclass
+    class Model2:
+        x: str
+
+    ta = TypeAdapter(Model2)
+    assert ta.validate_python({'x': 'ABC'}).x == 'abc'
+
+
 def test_pydantic_field_annotation():
     @pydantic.dataclasses.dataclass
     class Model:
@@ -2750,8 +2861,7 @@ def test_annotations_valid_for_field_inheritance() -> None:
         a: int = pydantic.dataclasses.Field()
 
     @pydantic.dataclasses.dataclass()
-    class B(A):
-        ...
+    class B(A): ...
 
     assert B.__pydantic_fields__['a'].annotation is int
 
@@ -2795,11 +2905,42 @@ def test_annotation_with_double_override() -> None:
         d: str = pydantic.dataclasses.Field()
 
     @pydantic.dataclasses.dataclass()
-    class C(B):
-        ...
+    class C(B): ...
 
     for class_ in [B, C]:
         instance = class_(a='a', b='b', c='c', d='d')
         for field_name in ['a', 'b', 'c', 'd']:
             assert class_.__pydantic_fields__[field_name].annotation is str
             assert getattr(instance, field_name) == field_name
+
+
+def test_schema_valid_for_inner_generic() -> None:
+    T = TypeVar('T')
+
+    @pydantic.dataclasses.dataclass()
+    class Inner(Generic[T]):
+        x: T
+
+    @pydantic.dataclasses.dataclass()
+    class Outer:
+        inner: Inner[int]
+
+    assert Outer(inner={'x': 1}).inner.x == 1
+    # note, this isn't Inner[Int] like it is for the BaseModel case, but the type of x is substituted, which is the important part
+    assert Outer.__pydantic_core_schema__['schema']['fields'][0]['schema']['cls'] == Inner
+    assert (
+        Outer.__pydantic_core_schema__['schema']['fields'][0]['schema']['schema']['fields'][0]['schema']['type']
+        == 'int'
+    )
+
+
+def test_validation_works_for_cyclical_forward_refs() -> None:
+    @pydantic.dataclasses.dataclass()
+    class X:
+        y: Union['Y', None]
+
+    @pydantic.dataclasses.dataclass()
+    class Y:
+        x: Union[X, None]
+
+    assert Y(x={'y': None}).x.y is None
