@@ -1,11 +1,11 @@
 import pickle
 from datetime import date, datetime
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, Generic, List, Optional, Union
 
 import pytest
 from pydantic_core import CoreSchema
 from pydantic_core.core_schema import SerializerFunctionWrapHandler
-from typing_extensions import Annotated, Literal
+from typing_extensions import Annotated, Literal, TypeVar
 
 from pydantic import (
     Base64Str,
@@ -213,6 +213,7 @@ def test_assignment():
 def test_model_validator_before():
     class Model(RootModel[int]):
         @model_validator(mode='before')
+        @classmethod
         def words(cls, v):
             if v == 'one':
                 return 1
@@ -648,3 +649,34 @@ def test_model_validate_strings(root_type, input_value, expected, raises_match,
             Model.model_validate_strings(input_value, strict=strict)
     else:
         assert Model.model_validate_strings(input_value, strict=strict).root == expected
+
+
+def test_model_construction_with_invalid_generic_specification() -> None:
+    T_ = TypeVar('T_', bound=BaseModel)
+
+    with pytest.raises(TypeError, match='You should parametrize RootModel directly'):
+
+        class GenericRootModel(RootModel, Generic[T_]):
+            root: Union[T_, int]
+
+
+def test_model_with_field_description() -> None:
+    class AModel(RootModel):
+        root: int = Field(description='abc')
+
+    assert AModel.model_json_schema() == {'title': 'AModel', 'type': 'integer', 'description': 'abc'}
+
+
+def test_model_with_both_docstring_and_field_description() -> None:
+    """Check if the docstring is used as the description when both are present."""
+
+    class AModel(RootModel):
+        """More detailed description"""
+
+        root: int = Field(description='abc')
+
+    assert AModel.model_json_schema() == {
+        'title': 'AModel',
+        'type': 'integer',
+        'description': 'More detailed description',
+    }
