@@ -1,12 +1,12 @@
 import contextlib
 import re
-import sys
 from collections import deque
 from dataclasses import dataclass
 from datetime import date, datetime
 from enum import Enum
 from functools import partial, partialmethod
 from itertools import product
+from os.path import normcase
 from typing import Any, Callable, Deque, Dict, FrozenSet, List, NamedTuple, Optional, Tuple, Union
 from unittest.mock import MagicMock
 
@@ -64,7 +64,6 @@ def test_annotated_validator_before() -> None:
     assert Model(x='1.0').x == 1.0
 
 
-@pytest.mark.xfail(sys.version_info >= (3, 9) and sys.implementation.name == 'pypy', reason='PyPy 3.9+ bug')
 def test_annotated_validator_builtin() -> None:
     """https://github.com/pydantic/pydantic/issues/6752"""
     TruncatedFloat = Annotated[float, BeforeValidator(int)]
@@ -556,17 +555,13 @@ def test_use_no_fields():
         class Model(BaseModel):
             a: str
 
-            with pytest.warns(PydanticDeprecatedSince20, match=V1_VALIDATOR_DEPRECATION_MATCH):
-
-                @validator()
-                def checker(cls, v):
-                    return v
+            @validator()
+            def checker(cls, v):
+                return v
 
 
 def test_use_no_fields_field_validator():
-    with pytest.raises(
-        TypeError, match=re.escape("field_validator() missing 1 required positional argument: '__field'")
-    ):
+    with pytest.raises(TypeError, match=re.escape("field_validator() missing 1 required positional argument: 'field'")):
 
         class Model(BaseModel):
             a: str
@@ -846,6 +841,18 @@ def test_validate_child_extra():
         Child(a='snap')
 
 
+def test_validate_all():
+    class MyModel(BaseModel):
+        x: int
+
+        @field_validator('*')
+        @classmethod
+        def validate_all(cls, v: Any):
+            return v * 2
+
+    assert MyModel(x=10).x == 20
+
+
 def test_validate_child_all():
     with pytest.warns(PydanticDeprecatedSince20, match=V1_VALIDATOR_DEPRECATION_MATCH):
 
@@ -865,6 +872,22 @@ def test_validate_child_all():
         with pytest.raises(ValidationError):
             Child(a='snap')
 
+    class Parent(BaseModel):
+        a: str
+
+    class Child(Parent):
+        @field_validator('*')
+        @classmethod
+        def check_a(cls, v: Any):
+            if 'foobar' not in v:
+                raise ValueError('"foobar" not found in a')
+            return v
+
+    assert Parent(a='this is not a child').a == 'this is not a child'
+    assert Child(a='this is foobar good').a == 'this is foobar good'
+    with pytest.raises(ValidationError):
+        Child(a='snap')
+
 
 def test_validate_parent():
     class Parent(BaseModel):
@@ -911,6 +934,26 @@ def test_validate_parent_all():
         with pytest.raises(ValidationError):
             Child(a='snap')
 
+    class Parent(BaseModel):
+        a: str
+
+        @field_validator('*')
+        @classmethod
+        def check_a(cls, v: Any):
+            if 'foobar' not in v:
+                raise ValueError('"foobar" not found in a')
+            return v
+
+    class Child(Parent):
+        pass
+
+    assert Parent(a='this is foobar good').a == 'this is foobar good'
+    assert Child(a='this is foobar good').a == 'this is foobar good'
+    with pytest.raises(ValidationError):
+        Parent(a='snap')
+    with pytest.raises(ValidationError):
+        Child(a='snap')
+
 
 def test_inheritance_keep():
     class Parent(BaseModel):
@@ -1049,8 +1092,7 @@ def test_validation_each_item_invalid_type():
 
                 @validator('foobar', each_item=True)
                 @classmethod
-                def check_foobar(cls, v: Any):
-                    ...
+                def check_foobar(cls, v: Any): ...
 
 
 def test_validation_each_item_nullable():
@@ -1300,20 +1342,20 @@ def test_assert_raises_validation_error():
         @field_validator('a')
         @classmethod
         def check_a(cls, v: Any):
-            assert v == 'a', 'invalid a'
+            if v != 'a':
+                raise AssertionError('invalid a')
             return v
 
     Model(a='a')
 
     with pytest.raises(ValidationError) as exc_info:
         Model(a='snap')
-    injected_by_pytest = "assert 'snap' == 'a'\n  - a\n  + snap"
     assert exc_info.value.errors(include_url=False) == [
         {
-            'ctx': {'error': HasRepr(repr(AssertionError("invalid a\nassert 'snap' == 'a'\n  - a\n  + snap")))},
+            'ctx': {'error': HasRepr(repr(AssertionError('invalid a')))},
             'input': 'snap',
             'loc': ('a',),
-            'msg': f'Assertion failed, invalid a\n{injected_by_pytest}',
+            'msg': 'Assertion failed, invalid a',
             'type': 'assertion_error',
         }
     ]
@@ -1742,6 +1784,7 @@ def test_overridden_root_validators():
         x: str
 
         @model_validator(mode='before')
+        @classmethod
         def pre_root(cls, values: Dict[str, Any]) -> Dict[str, Any]:
             validate_stub('A', 'pre')
             return values
@@ -1753,6 +1796,7 @@ def test_overridden_root_validators():
 
     class B(A):
         @model_validator(mode='before')
+        @classmethod
         def pre_root(cls, values: Dict[str, Any]) -> Dict[str, Any]:
             validate_stub('B', 'pre')
             return values
@@ -1807,6 +1851,7 @@ def test_validating_assignment_model_validator_before_fail():
         model_config = ConfigDict(validate_assignment=True)
 
         @model_validator(mode='before')
+        @classmethod
         def values_are_not_string(cls, values: Dict[str, Any]) -> Dict[str, Any]:
             assert isinstance(values, dict)
             if any(isinstance(x, str) for x in values.values()):
@@ -1916,7 +1961,7 @@ def test_v1_validator_deprecated():
     # check that we got stacklevel correct
     # if this fails you need to edit the stacklevel
     # parameter to warnings.warn in _decorators.py
-    assert w.filename == __file__
+    assert normcase(w.filename) == normcase(__file__)
     source = _get_source_line(w.filename, w.lineno)
     assert "@validator('x')" in source
 
@@ -2015,8 +2060,7 @@ def test_v1_validator_signature_kwargs_not_allowed() -> None:
                 a: int
 
                 @validator('a')
-                def check_a(cls, value: Any, foo: Any) -> Any:
-                    ...
+                def check_a(cls, value: Any, foo: Any) -> Any: ...
 
 
 def test_v1_validator_signature_kwargs1() -> None:
@@ -2093,8 +2137,7 @@ def test_v1_validator_signature_with_field() -> None:
                 b: int
 
                 @validator('b')
-                def check_b(cls, value: Any, field: Any) -> Any:
-                    ...
+                def check_b(cls, value: Any, field: Any) -> Any: ...
 
 
 def test_v1_validator_signature_with_config() -> None:
@@ -2106,8 +2149,7 @@ def test_v1_validator_signature_with_config() -> None:
                 b: int
 
                 @validator('b')
-                def check_b(cls, value: Any, config: Any) -> Any:
-                    ...
+                def check_b(cls, value: Any, config: Any) -> Any: ...
 
 
 def test_model_config_validate_default():
@@ -2507,6 +2549,9 @@ def test_validator_allow_reuse_different_field_4():
     assert Model(x=1, y=2).model_dump() == {'x': 2, 'y': 3}
 
 
+@pytest.mark.filterwarnings(
+    'ignore:Pydantic V1 style `@root_validator` validators are deprecated.*:pydantic.warnings.PydanticDeprecatedSince20'
+)
 def test_root_validator_allow_reuse_same_field():
     with pytest.warns(UserWarning, match='`root_val` overrides an existing Pydantic `@root_validator` decorator'):
 
@@ -2839,3 +2884,17 @@ def test_plain_validator_with_unsupported_type() -> None:
     model = type_adapter.validate_python('abcdefg')
     assert isinstance(model, UnsupportedClass)
     assert isinstance(type_adapter.dump_python(model), UnsupportedClass)
+
+
+def test_validator_with_default_values() -> None:
+    def validate_x(v: int, unrelated_arg: int = 1, other_unrelated_arg: int = 2) -> int:
+        assert v != -1
+        return v
+
+    class Model(BaseModel):
+        x: int
+
+        val_x = field_validator('x')(validate_x)
+
+    with pytest.raises(ValidationError):
+        Model(x=-1)
